@@ -14,19 +14,19 @@ plotrd<-function(clustrdOut,what=c("all","all"),obslabel=0,attlabel=0,density=T,
   if(attlabel[1]==0){
     attlabel=paste("v.",1:nrow(dfAtt),sep="")
   }
-  
   dfAtt$itlab=attlabel
+
   if (density==T) {
     dmap=ggplot(df,aes(x=x1,y=x2))+stat_density2d(aes(fill=..level..), geom="polygon") + scale_fill_gradient(low="lightyellow", high="blue")+ theme_bw()
   }
   else {
     dmap=ggplot(df,aes(x=x1,y=x2)) + theme_bw()
   }
-  dmap=dmap + xlim(min(df$x1,dfAtt$x1,dfG$x1),max(df$x1,dfAtt$x1,dfG$x1))
-  dmap=dmap + ylim(min(df$x2,dfAtt$x2,dfG$x2),max(df$x2,dfAtt$x2,dfG$x2))
   
   
   if (what[1] == "all" & what[2] == "all") {
+    dmap=dmap + xlim(min(df$x1,dfAtt$x1,dfG$x1),max(df$x1,dfAtt$x1,dfG$x1))
+    dmap=dmap + ylim(min(df$x2,dfAtt$x2,dfG$x2),max(df$x2,dfAtt$x2,dfG$x2))
     dmap=dmap + geom_text(data=df,aes(x=x1,y=x2,label=obslab),colour="black")
     dmap=dmap + geom_text(data=dfAtt,aes(x=x1,y=x2,label=itlab),colour="darkgreen")
     dmap= dmap+ geom_point(data=df,aes(x=x1,y=x2,colour=group),alpha=.25)
@@ -34,10 +34,14 @@ plotrd<-function(clustrdOut,what=c("all","all"),obslabel=0,attlabel=0,density=T,
     
   }
   else if (what[1] == "none" & what[2] == "all") {
+    dmap=dmap + xlim(min(dfAtt$x1,dfG$x1),max(dfAtt$x1,dfG$x1))
+    dmap=dmap + ylim(min(dfAtt$x2,dfG$x2),max(dfAtt$x2,dfG$x2))
     dmap=dmap + geom_text(data=dfAtt,aes(x=x1,y=x2,label=itlab),colour="darkgreen")
     dmap=dmap + geom_point(data=dfG,aes(x=x1,y=x2),colour="red",size=5)
   }
   else if (what[1] == "all" & what[2] == "none") {
+    dmap=dmap + xlim(min(df$x1,dfG$x1),max(df$x1,dfG$x1))
+    dmap=dmap + ylim(min(df$x2,dfG$x2),max(df$x2,dfG$x2))
     dmap=dmap + geom_text(data=df,aes(x=x1,y=x2,colour=group,label=obslab))
     dmap=dmap + geom_point(data=dfG,aes(x=x1,y=x2),colour="red",size=5)
   }  
